var NAVTREEINDEX0 =
{
"Point_set_processing_3_2average_spacing_example_8cpp-example.html":[4,4],
"Point_set_processing_3_2bilateral_smooth_point_set_example_8cpp-example.html":[4,19],
"Point_set_processing_3_2callback_example_8cpp-example.html":[4,23],
"Point_set_processing_3_2clustering_example_8cpp-example.html":[4,10],
"Point_set_processing_3_2edge_aware_upsample_point_set_example_8cpp-example.html":[4,20],
"Point_set_processing_3_2edges_example_8cpp-example.html":[4,21],
"Point_set_processing_3_2grid_simplification_example_8cpp-example.html":[4,12],
"Point_set_processing_3_2grid_simplify_indices_8cpp-example.html":[4,13],
"Point_set_processing_3_2hierarchy_simplification_example_8cpp-example.html":[4,14],
"Point_set_processing_3_2jet_smoothing_example_8cpp-example.html":[4,15],
"Point_set_processing_3_2normals_example_8cpp-example.html":[4,16],
"Point_set_processing_3_2orient_scanlines_example_8cpp-example.html":[4,17],
"Point_set_processing_3_2poisson_eliminate_example_8cpp-example.html":[4,24],
"Point_set_processing_3_2poisson_eliminate_from_mesh_example_8cpp-example.html":[4,25],
"Point_set_processing_3_2read_las_example_8cpp-example.html":[4,2],
"Point_set_processing_3_2read_ply_points_with_colors_example_8cpp-example.html":[4,1],
"Point_set_processing_3_2read_write_xyz_point_set_example_8cpp-example.html":[4,0],
"Point_set_processing_3_2registration_with_OpenGR_8cpp-example.html":[4,7],
"Point_set_processing_3_2registration_with_opengr_pointmatcher_pipeline_8cpp-example.html":[4,9],
"Point_set_processing_3_2registration_with_pointmatcher_8cpp-example.html":[4,8],
"Point_set_processing_3_2remove_outliers_example_8cpp-example.html":[4,11],
"Point_set_processing_3_2scale_estimation_2d_example_8cpp-example.html":[4,6],
"Point_set_processing_3_2scale_estimation_example_8cpp-example.html":[4,5],
"Point_set_processing_3_2structuring_example_8cpp-example.html":[4,22],
"Point_set_processing_3_2wlop_simplify_and_regularize_point_set_example_8cpp-example.html":[4,18],
"Point_set_processing_3_2write_ply_points_example_8cpp-example.html":[4,3],
"annotated.html":[3],
"citelist.html":[2],
"classCGAL_1_1Point__set__with__structure.html":[1,0,0,1],
"classCGAL_1_1Point__set__with__structure.html#a002ef0fb6a37d8c5146b928ad02fa020":[1,0,0,1,2],
"classCGAL_1_1Point__set__with__structure.html#a4974a2fd2a8bfeb1aee2c0ae8a8b899b":[1,0,0,1,7],
"classCGAL_1_1Point__set__with__structure.html#a5fce6a2330dba7606f964c09d915c9c3":[1,0,0,1,1],
"classCGAL_1_1Point__set__with__structure.html#a61960490d2331f54aad4892486be67c4":[1,0,0,1,5],
"classCGAL_1_1Point__set__with__structure.html#a7a963f81f59db7dfeba4ca94f69d22c1":[1,0,0,1,8],
"classCGAL_1_1Point__set__with__structure.html#aaada4e3848c92698219ee8899b996aaa":[1,0,0,1,3],
"classCGAL_1_1Point__set__with__structure.html#aaada4e3848c92698219ee8899b996aaaa6651bbaf37b21104a6e65bf180f8dfff":[1,0,0,1,3,3],
"classCGAL_1_1Point__set__with__structure.html#aaada4e3848c92698219ee8899b996aaaa88f9a1f5e8dd10f37db7ebd4d99fe28d":[1,0,0,1,3,0],
"classCGAL_1_1Point__set__with__structure.html#aaada4e3848c92698219ee8899b996aaaad5c5bd81e6597d40bb9d8fe7e5c76ffc":[1,0,0,1,3,2],
"classCGAL_1_1Point__set__with__structure.html#aaada4e3848c92698219ee8899b996aaaaee5b7d59600dec0ebfd54993b9f26381":[1,0,0,1,3,1],
"classCGAL_1_1Point__set__with__structure.html#aaada4e3848c92698219ee8899b996aaaaf67df8f4858ebfde72e1c5d77a41395d":[1,0,0,1,3,4],
"classCGAL_1_1Point__set__with__structure.html#ab5a120ef52f43b2af08580d7c67dd473":[1,0,0,1,0],
"classCGAL_1_1Point__set__with__structure.html#ac8c3156f0e2ffdc7d45ba376a3bc90d8":[1,0,0,1,4],
"classCGAL_1_1Point__set__with__structure.html#adefa2624e55ad8398784aa97f1362040":[1,0,0,1,10],
"classCGAL_1_1Point__set__with__structure.html#ae3cfc8660cb6151865d8d6c02e3982f5":[1,0,0,1,9],
"classCGAL_1_1Point__set__with__structure.html#ae8890334744d8d7efd17917c62fc1513":[1,0,0,1,6],
"examples.html":[4],
"group__PkgPointSetProcessing3Algorithms.html":[1,0,0],
"group__PkgPointSetProcessing3Algorithms.html#ga01192a227578fee0c5676ba6a5e88931":[1,0,0,2],
"group__PkgPointSetProcessing3Algorithms.html#ga078e25209373cab0e1f3524202489771":[1,0,0,15],
"group__PkgPointSetProcessing3Algorithms.html#ga17c3c558c3799b65bd23fba971a82a5c":[1,0,0,17],
"group__PkgPointSetProcessing3Algorithms.html#ga2531a1366bea67edef99e87d6b8819ec":[1,0,0,3],
"group__PkgPointSetProcessing3Algorithms.html#ga258a9b3a40d10533f8f01d64b4e91eca":[1,0,0,7],
"group__PkgPointSetProcessing3Algorithms.html#ga28fe6443638647be0874b283085eb2cd":[1,0,0,10],
"group__PkgPointSetProcessing3Algorithms.html#ga2d2e21a8a49472a5ed1254f42978608e":[1,0,0,21],
"group__PkgPointSetProcessing3Algorithms.html#ga2d73d46ca766656a219bf5e6045b837a":[1,0,0,19],
"group__PkgPointSetProcessing3Algorithms.html#ga3420351b6d3fad079d13f894f42e9d03":[1,0,0,14],
"group__PkgPointSetProcessing3Algorithms.html#ga4be2d94f1791d24b8ba0107bc33ad6dc":[1,0,0,20],
"group__PkgPointSetProcessing3Algorithms.html#ga50c708584a8219847ce04f636dcad4b3":[1,0,0,23],
"group__PkgPointSetProcessing3Algorithms.html#ga6e2493a424482f07d766f12fedefedd0":[1,0,0,11],
"group__PkgPointSetProcessing3Algorithms.html#ga721aeb7af4b2d31e08e75bc5d53303cf":[1,0,0,18],
"group__PkgPointSetProcessing3Algorithms.html#ga771cd5e756daee1deab68c8bf65d8058":[1,0,0,6],
"group__PkgPointSetProcessing3Algorithms.html#ga7757ef9b3900e42fde26f5a0ac56e20f":[1,0,0,13],
"group__PkgPointSetProcessing3Algorithms.html#ga79ee6fb524ec53b9b85eb32e7ae56ca8":[1,0,0,29],
"group__PkgPointSetProcessing3Algorithms.html#ga8712cbc64f1cfd4dd2f61049a24b90f4":[1,0,0,8],
"group__PkgPointSetProcessing3Algorithms.html#ga8b330397a3fb68176c851fd7d214b513":[1,0,0,4],
"group__PkgPointSetProcessing3Algorithms.html#ga8c6af1df54e336bd0b9a2de6b909bccf":[1,0,0,9],
"group__PkgPointSetProcessing3Algorithms.html#ga96a3738be3b2b9bd1587af78ae10e67a":[1,0,0,16],
"group__PkgPointSetProcessing3Algorithms.html#gaa849870cbc74cee3f2f536c70aadf976":[1,0,0,22],
"group__PkgPointSetProcessing3Algorithms.html#gaab0fd78ef3e46c4256e9a1145a9d118e":[1,0,0,26],
"group__PkgPointSetProcessing3Algorithms.html#gac57ce53e3249a66e4c19e85f439ff01e":[1,0,0,28],
"group__PkgPointSetProcessing3Algorithms.html#gaea71f355f996784df500a2a58809b9c5":[1,0,0,5],
"group__PkgPointSetProcessing3Algorithms.html#gaebbc04909dfd575a94f932c8d3bacdce":[1,0,0,25],
"group__PkgPointSetProcessing3Algorithms.html#gaf1e415a68652535215c60bc52ebacca3":[1,0,0,27],
"group__PkgPointSetProcessing3Algorithms.html#gaf45220685eff6649d29f600eb66fb6c1":[1,0,0,12],
"group__PkgPointSetProcessing3Algorithms.html#gafc3627234666e1fb458e9387e9d5f3c6":[1,0,0,24],
"group__PkgPointSetProcessing3IO.html":[1,0,1],
"group__PkgPointSetProcessing3IO.html#ga5822feba4449f0492363611620b877c0":[1,0,1,1],
"group__PkgPointSetProcessing3IO.html#ga8fac388459c5cf96bf11ce3b4e0459c1":[1,0,1,0],
"group__PkgPointSetProcessing3IOLas.html":[1,0,5],
"group__PkgPointSetProcessing3IOLas.html#ga199f672f2decde903ca1ae1af0a02ece":[1,0,5,5],
"group__PkgPointSetProcessing3IOLas.html#ga3689f3b5e3c58d217b56915af9fddfb5":[1,0,5,2],
"group__PkgPointSetProcessing3IOLas.html#ga39f95610b08508016f88790086e5c008":[1,0,5,3],
"group__PkgPointSetProcessing3IOLas.html#ga5187fc18430a5e3c811f75da57a057ad":[1,0,5,4],
"group__PkgPointSetProcessing3IOLas.html#ga912d110b39abc211a85240def2ca2317":[1,0,5,0],
"group__PkgPointSetProcessing3IOLas.html#ga9b581aa551033a9ec7a44ff6d8d9e3b7":[1,0,5,6],
"group__PkgPointSetProcessing3IOLas.html#gae7018ffb846e16d416a9bf90f7ca6e98":[1,0,5,1],
"group__PkgPointSetProcessing3IOLas.html#gafaeb3b48279532412ec422c90a7f05fc":[1,0,5,7],
"group__PkgPointSetProcessing3IOOff.html":[1,0,2],
"group__PkgPointSetProcessing3IOOff.html#ga54724feeef37245ee2ff86f32726fc74":[1,0,2,2],
"group__PkgPointSetProcessing3IOOff.html#gab25342566e9141657969a01cdcf3545f":[1,0,2,1],
"group__PkgPointSetProcessing3IOOff.html#gae672e21348cad0a7ce819298f99444e7":[1,0,2,0],
"group__PkgPointSetProcessing3IOOff.html#gaf3b2a435f815f37f914fe9effbf6de73":[1,0,2,3],
"group__PkgPointSetProcessing3IOPly.html":[1,0,4],
"group__PkgPointSetProcessing3IOPly.html#ga01ab7639f85c8dd1d5e9f66065038c58":[1,0,4,4],
"group__PkgPointSetProcessing3IOPly.html#ga39edb018d7641c169ff00154eac4a6d5":[1,0,4,2],
"group__PkgPointSetProcessing3IOPly.html#ga4375e15f5ec01c7aca1006e216efe4c6":[1,0,4,1],
"group__PkgPointSetProcessing3IOPly.html#ga615f4420ce82b5ceb1b584b506d714ad":[1,0,4,9],
"group__PkgPointSetProcessing3IOPly.html#ga6433f03251832d3904ec19ddd5b84880":[1,0,4,5],
"group__PkgPointSetProcessing3IOPly.html#ga80830a581fb424153bf1d0476112f375":[1,0,4,8],
"group__PkgPointSetProcessing3IOPly.html#ga818eed34a10f3bde53ac5a23d5bbddd6":[1,0,4,3],
"group__PkgPointSetProcessing3IOPly.html#gac1fd90a9d5266e631c68cb31bfe31516":[1,0,4,10],
"group__PkgPointSetProcessing3IOPly.html#gad9785e7191ba94d81fac841798aa1ddb":[1,0,4,7],
"group__PkgPointSetProcessing3IOPly.html#gaf5c12b5bab6f88a9d22d425b1ab2586a":[1,0,4,6],
"group__PkgPointSetProcessing3IOXyz.html":[1,0,3],
"group__PkgPointSetProcessing3IOXyz.html#ga14eed6b863a42b99c7dc68ad8e1a35f0":[1,0,3,2],
"group__PkgPointSetProcessing3IOXyz.html#ga1991ab8d312de62ddd907f81890ed039":[1,0,3,3],
"group__PkgPointSetProcessing3IOXyz.html#ga45c8d8303cf00701660c946395499588":[1,0,3,0],
"group__PkgPointSetProcessing3IOXyz.html#ga7d8cfbc64a9f01efcca7490caf11f763":[1,0,3,1],
"group__PkgPointSetProcessing3Ref.html":[1,0],
"index.html":[],
"index.html":[0],
"index.html#Point_set_processing_3API":[0,1],
"index.html#Point_set_processing_3Bilateral_smoothing_parallel_performance":[0,9,1,0],
"index.html#Point_set_processing_3Callbacks":[0,15],
"index.html#Point_set_processing_3Clustering":[0,6],
"index.html#Point_set_processing_3Example_9":[0,14,0],
"index.html#Point_set_processing_3Example_average_spacing":[0,3,0],
"index.html#Point_set_processing_3Example_bilateral_smoothing":[0,9,1],
"index.html#Point_set_processing_3Example_callbacks":[0,15,0],
"index.html#Point_set_processing_3Example_clustering":[0,6,0],
"index.html#Point_set_processing_3Example_grid_simplification":[0,8,0],
"index.html#Point_set_processing_3Example_hierarchy_simplication":[0,8,1],
"index.html#Point_set_processing_3Example_io":[0,2,0,0],
"index.html#Point_set_processing_3Example_jet_smoothing":[0,9,0],
"index.html#Point_set_processing_3Example_las_read":[0,2,1,2],
"index.html#Point_set_processing_3Example_normals":[0,11,0,0],
"index.html#Point_set_processing_3Example_outlier_removal":[0,7,0],
"index.html#Point_set_processing_3Example_ply_read":[0,2,1,1],
"index.html#Point_set_processing_3Example_ply_write":[0,2,1,0],
"index.html#Point_set_processing_3Example_poisson_elimination":[0,8,3,0],
"index.html#Point_set_processing_3Example_poisson_elimination_on_mesh":[0,8,3,1],
"index.html#Point_set_processing_3Example_scale_estimation_global":[0,4,0],
"index.html#Point_set_processing_3Example_scale_estimation_local":[0,4,1],
"index.html#Point_set_processing_3Example_scanline_normals":[0,11,1,0],
"index.html#Point_set_processing_3Example_sharp_edges":[0,13,0],
"index.html#Point_set_processing_3Example_upsampling":[0,12,0],
"index.html#Point_set_processing_3Example_wlop":[0,8,2],
"index.html#Point_set_processing_3Examples_registration_OpenGR":[0,5,0],
"index.html#Point_set_processing_3Examples_registration_OpenGR_PointMatcher_Pipeline":[0,5,2],
"index.html#Point_set_processing_3Examples_registration_OpenGR_parameter_accuracy":[0,5,0,1],
"index.html#Point_set_processing_3Examples_registration_OpenGR_parameter_maximum_running_time":[0,5,0,4],
"index.html#Point_set_processing_3Examples_registration_OpenGR_parameter_normal":[0,5,0,2],
"index.html#Point_set_processing_3Examples_registration_OpenGR_parameter_number_of_samples":[0,5,0,0],
"index.html#Point_set_processing_3Examples_registration_OpenGR_parameter_overlap":[0,5,0,3],
"index.html#Point_set_processing_3Examples_registration_PointMatcher":[0,5,1],
"index.html#Point_set_processing_3Examples_registration_PointMatcher_parameter_error_minimizer":[0,5,1,3],
"index.html#Point_set_processing_3Examples_registration_PointMatcher_parameter_inspector":[0,5,1,4],
"index.html#Point_set_processing_3Examples_registration_PointMatcher_parameter_logger":[0,5,1,5],
"index.html#Point_set_processing_3Examples_registration_PointMatcher_parameter_matcher":[0,5,1,1],
"index.html#Point_set_processing_3Examples_registration_PointMatcher_parameter_outlier_filters":[0,5,1,2],
"index.html#Point_set_processing_3Examples_registration_PointMatcher_parameter_point_set_filters":[0,5,1,0],
"index.html#Point_set_processing_3Examples_registration_PointMatcher_parameter_transformation":[0,5,1,6],
"index.html#Point_set_processing_3FeaturesEstimation":[0,13],
"index.html#Point_set_processing_3Hierarchy_simplification_parameter_size":[0,8,1,0],
"index.html#Point_set_processing_3Hierarchy_simplification_parameter_var_max":[0,8,1,1],
"index.html#Point_set_processing_3ImplementationHistory":[0,16],
"index.html#Point_set_processing_3InputOutput":[0,2],
"index.html#Point_set_processing_3Introduction":[0,0],
"index.html#Point_set_processing_3Mst_orient_normals":[0,11,0],
"index.html#Point_set_processing_3NamedParameters":[0,1,0],
"index.html#Point_set_processing_3NormalEstimation":[0,10],
"index.html#Point_set_processing_3NormalOrientation":[0,11],
"index.html#Point_set_processing_3Outdated":[0,1,2],
"index.html#Point_set_processing_3OutlierRemoval":[0,7],
"index.html#Point_set_processing_3Points_io":[0,2,0],
"index.html#Point_set_processing_3PoissonElimination":[0,8,3],
"index.html#Point_set_processing_3Properties_io":[0,2,1],
"index.html#Point_set_processing_3PropertyMaps":[0,1,1],
"index.html#Point_set_processing_3Registration":[0,5],
"index.html#Point_set_processing_3Scale":[0,4],
"index.html#Point_set_processing_3Scanline_orient_normals":[0,11,1],
"index.html#Point_set_processing_3Simplification":[0,8],
"index.html#Point_set_processing_3Smoothing":[0,9],
"index.html#Point_set_processing_3Spacing":[0,3],
"index.html#Point_set_processing_3Structuring":[0,14],
"index.html#Point_set_processing_3Upsample_Parameter1":[0,12,0,0],
"index.html#Point_set_processing_3Upsample_Parameter2":[0,12,0,1],
"index.html#Point_set_processing_3Upsampling":[0,12],
"index.html#Point_set_processing_3WLOP_Parameter":[0,8,2,0],
"index.html#Point_set_processing_3WLOP_parallel_performance":[0,8,2,2],
"index.html#Point_set_processing_3WLOP_parameter_neighborhood_size":[0,8,2,1],
"index.html#Point_set_processing_3upsample_neighborhood_size":[0,12,0,2],
"modules.html":[1],
"pages.html":[],
"structCGAL_1_1IO_1_1PLY__property.html":[1,0,4,0],
"structCGAL_1_1IO_1_1PLY__property.html#a0a689cd48fe319db0548e5da039ba2eb":[1,0,4,0,2],
"structCGAL_1_1IO_1_1PLY__property.html#aba3662647b017ded6f68b051afc2469c":[1,0,4,0,0],
"structCGAL_1_1IO_1_1PLY__property.html#ac26c8a067c099690feb847e5a6b2d6fd":[1,0,4,0,1],
"structCGAL_1_1pointmatcher_1_1ICP__config.html":[1,0,0,0],
"structCGAL_1_1pointmatcher_1_1ICP__config.html#a30540dba7014e719a42033770366c42f":[1,0,0,0,0],
"structCGAL_1_1pointmatcher_1_1ICP__config.html#acdd6795fe1bf84a7d55917d43d202767":[1,0,0,0,1]
};
